@@ -81,10 +81,10 @@ public class LdapCreateTableTask extends UpdateTaskAdapter {
     public void perform(PerformParameters params) throws OXException {
         Connection writeCon = params.getConnection();
         PreparedStatement stmt = null;
-        boolean rollback = false;
+        int rollback = 0;
         try {
             writeCon.setAutoCommit(false); // BEGIN
-            rollback = true;
+            rollback = 1;
 
             String[] tableNames = LdapCreateTableService.getTablesToCreate();
             String[] createStmts = LdapCreateTableService.getCreateStmts();
@@ -103,17 +103,19 @@ public class LdapCreateTableTask extends UpdateTaskAdapter {
             }
 
             writeCon.commit(); // COMMIT
-            rollback = false;
+            rollback = 2;
         } catch (OXException e) {
             throw e;
         } catch (Exception e) {
             throw LdapExceptionCodes.ERROR.create(e, e.getMessage());
         } finally {
             closeSQLStuff(stmt);
-            if (rollback) {
-                Databases.rollback(writeCon);
+            if (rollback > 0) {
+                if (rollback == 1) {
+                    Databases.rollback(writeCon);
+                }
+                Databases.autocommit(writeCon);
             }
-            Databases.autocommit(writeCon);
         }
     }
 
