@@ -146,20 +146,20 @@ public class LdapGlobalFolderCreator {
                 return executeQuery.getInt(1);
             }
             return -1;
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw e;
         } finally {
             if (null != executeQuery) {
                 try {
                     executeQuery.close();
-                } catch (final SQLException e) {
+                } catch (SQLException e) {
                     LOG.error("", e);
                 }
             }
             if (null != ps) {
                 try {
                     ps.close();
-                } catch (final SQLException e) {
+                } catch (SQLException e) {
                     LOG.error("", e);
                 }
             }
@@ -299,6 +299,11 @@ public class LdapGlobalFolderCreator {
                 return false;
             }
 
+            @Override
+            public boolean isStaySignedIn() {
+                return false;
+            }
+
             @Override
             public Set<String> getParameterNames() {
                 return Collections.emptySet();
